@@ -97,14 +97,26 @@ class GetMediaShowItemView(BrowserView):
         """ Finds and returns the type of lead media
         """ 
         item = self.context
-        if(self.isVideo(item)):
-            return "Video"
-        elif item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
-            return "Youtube"
-        elif item.portal_type == 'Link' and item.remoteUrl.find("vimeo.com") > -1:
-            return "Vimeo"
-        else:
-            return "Image"
+        
+        try:
+            if(self.isVideo(item)):
+                return "Video"
+            elif item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+                return "Youtube"
+            elif item.portal_type == 'Link' and item.remoteUrl.find("vimeo.com") > -1:
+                return "Vimeo"
+            else:
+                return "Image"
+        except:
+            if(self.isVideo(item)):
+                return "Video"
+            elif item.portal_type == 'Link' and item.getObject().remoteUrl.find("youtube.com") > -1:
+                return "Youtube"
+            elif item.portal_type == 'Link' and item.getObject().remoteUrl.find("vimeo.com") > -1:
+                return "Vimeo"
+            else:
+                return "Image"
+    
     
     def isVideo(self, item):
         if FLOWPLAYER_EXISTS:
@@ -166,7 +178,7 @@ class MediaShowListingView(BrowserView):
         
         #Python to JSON encoding
         for res in results:
-            if self.getMediaURL(res.getObject()) != "" and self.canView(res.getObject()) :
+            if self.getMediaURL(res.getObject()) != "":
                 resultArray.append({"url": res.getURL(), "UID": res["UID"]})
 
         jsonStr = json.dumps(resultArray[:100])
@@ -200,7 +212,10 @@ class MediaShowListingView(BrowserView):
                 if leadMedia.portal_type == 'Image':
                     return leadMedia.getURL() + '/image_large'
                 elif leadMedia.portal_type == 'Link':
-                    return leadMedia.remoteUrl
+                    try:
+                        return leadMedia.remoteUrl
+                    except:
+                        return leadMedia.getObject().remoteUrl
                 else:
                     return leadMedia.getURL()
             else:
